#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_IF_ALLBITS_ELSE_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_IF_ALLBITS_ELSE_HPP_INCLUDED

#include <nt2/boolean/include/functions/scalar/if_allbits_else.hpp>

#endif
